#!/bin/sh

set -e

SCRIPT_HOME=$(dirname "$0")
SCRIPT_HOME="`cd \"${SCRIPT_HOME}\" >/dev/null && pwd`"
SCRIPT_FOLDER="`basename $(dirname "$SCRIPT_HOME")`"


# ----- modify default settings -----

JS_RELEASE_DEFAULT="2.4.0-SNAPSHOT"

JS_REPOSITORY="sosberlin/jobscheduler"
# JS_IMAGE="$(basename "${SCRIPT_HOME}")-${JS_RELEASE//\./-}"
JS_IMAGE="$(basename "$SCRIPT_HOME")"

JS_USER_ID_DEFAULT="$UID"

JS_HTTP_PORT_DEFAULT="4445"
JS_HTTPS_PORT_DEFAULT="4443"

JS_JAVA_OPTIONS_DEFAULT="-Xmx500m"
JS_BUILD_ARGS_DEFAULT=

# ----- modify default settings -----


if [ -f "$HOME/.js_profile_${SCRIPT_FOLDER}" ]
then
  echo ".. running profile: $HOME/.js_profile_${SCRIPT_FOLDER}"

  if [ ! -x "$HOME/.js_profile_${SCRIPT_FOLDER}" ]
  then
    chmod u+x $HOME/.js_profile_${SCRIPT_FOLDER}
  fi

  . $HOME/.js_profile_${SCRIPT_FOLDER}
fi

if [ -f "$HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE" ]
then
  echo ".. running profile: $HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE"

  if [ ! -x "$HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE" ]
  then
    chmod u+x $HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE
  fi

  . $HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE
fi

JS_TARGETS="powershell"
PS_ARG_PACKAGE_URL=""
PS_ARG_PACKAGE_RELEASE=""
PS_ARG_MODULE_URL=""

for option in "$@"
do
  case "$option" in
         --targets=*) JS_TARGETS=(`echo "$option" | sed 's/--targets=//' | sed -r 's/[,]+/ /g'`)
                      ;;
         *)           echo "unknown argument: $option"
                      exit 1
                      ;;
  esac
done

JS_DOCKERFILE="$SCRIPT_HOME/build/Dockerfile.tmp"
cp -p $SCRIPT_HOME/build/Dockerfile $JS_DOCKERFILE

for t in ${JS_TARGETS[@]}; do
  if [ ! -f "$SCRIPT_HOME/build/Dockerfile.$t" ]
  then
    echo "Dockerfile missing for target '$t': $SCRIPT_HOME/build/Dockerfile.$t"
    exit 1
  fi

  sed -e "/<$t>/r $SCRIPT_HOME/build/Dockerfile.$t" -e "/<$t>/d" -i $JS_DOCKERFILE

  if [ $t = "powershell" ]
  then
    # PS_RELEASE_URL=(`curl -s https://api.github.com/repos/PowerShell/PowerShell/releases/latest | grep linux-alpine-x64 | cut -d '"' -f 4`)
    # echo "PS_RELEASE_URL=$PS_RELEASE_URL"
    # PS_PACKAGE_URL=(`curl -s ${PS_RELEASE_URL} | grep browser_download_url | grep linux-alpine-x64 | cut -d '"' -f 4`)
    # echo "PS_PACKAGE_URL=$PS_PACKAGE_URL"
    # PS_PACKAGE_RELEASE=(`curl -s ${PS_RELEASE_URL} | grep tag_name | cut -d '"' -f 4 | cut -c 2-`)
    # echo "PS_PACKAGE_RELEASE=$PS_PACKAGE_RELEASE"

    PS_ARG_PACKAGE_URL="--build-arg=PS_PACKAGE_URL=https://github.com/PowerShell/PowerShell/releases/download/v7.4.1/powershell-7.4.1-linux-x64.tar.gz"
    PS_ARG_PACKAGE_RELEASE="--build-arg=PS_PACKAGE_RELEASE=7.4.1"
    # echo "PS_ARG_PACKAGE_URL=$PS_ARG_PACKAGE_URL"
    # echo "PS_ARG_PACKAGE_RELEASE=$PS_ARG_PACKAGE_RELEASE"   

    PS_MODULE_URL=(`curl -s https://api.github.com/repos/sos-berlin/js7-cli-powershell/releases/latest | grep tarball_url | cut -d '"' -f 4`)
    PS_ARG_MODULE_URL="--build-arg=PS_MODULE_URL=${PS_MODULE_URL}"
    # PS_ARG_MODULE_URL="--build-arg=PS_MODULE_URL=https://api.github.com/repos/sos-berlin/js7-cli-powershell/tarball/v.2.0.2-SNAPSHOT"
  fi
done

JS_RELEASE="${JS_RELEASE:-$JS_RELEASE_DEFAULT}"
JS_USER_ID="${JS_USER_ID:-$JS_USER_ID_DEFAULT}"
JS_HTTP_PORT="${JS_HTTP_PORT:-$JS_HTTP_PORT_DEFAULT}"
JS_HTTPS_PORT="${JS_HTTPS_PORT:-$JS_HTTPS_PORT_DEFAULT}"
JS_JAVA_OPTIONS="${JS_JAVA_OPTIONS:-$JS_JAVA_OPTIONS_DEFAULT}"
JS_BUILD_ARGS="${JS_BUILD_ARGS:-$JS_BUILD_ARGS_DEFAULT}"

set -x

docker build --no-cache --rm \
      --tag=$JS_REPOSITORY:$JS_IMAGE \
      --file=$JS_DOCKERFILE \
      --build-arg="JS_RELEASE=$JS_RELEASE" \
      --build-arg="JS_RELEASE_MAJOR=$(echo $JS_RELEASE | cut -d . -f 1,2)" \
      --build-arg="JS_USER_ID=$JS_USER_ID" \
      --build-arg="JS_HTTP_PORT=$JS_HTTP_PORT" \
      --build-arg="JS_HTTPS_PORT=$JS_HTTPS_PORT" \
      --build-arg="JS_JAVA_OPTIONS=$JS_JAVA_OPTIONS" \
      $PS_ARG_PACKAGE_URL \
      $PS_ARG_PACKAGE_RELEASE \
      $PS_ARG_MODULE_URL \
      $JS_BUILD_ARGS $SCRIPT_HOME/build

set +x

unset JS_REPOSITORY
unset JS_IMAGE
unset JS_RELEASE
unset JS_USER_ID
unset JS_HTTP_PORT
unset JS_HTTPS_PORT
unset JS_JAVA_OPTIONS
unset JS_BUILD_ARGS
unset JS_TARGETS
unset JS_DOCKERFILE
unset PS_ARG_PACKAGE_URL
unset PS_ARG_PACKAGE_RELEASE
unset PS_ARG_MODULE_URL

