#!/bin/sh

set -e

SCRIPT_HOME=$(dirname "$0")
SCRIPT_HOME="`cd \"${SCRIPT_HOME}\" >/dev/null && pwd`"
SCRIPT_FOLDER="`basename $(dirname "$SCRIPT_HOME")`"

IMAGE_NAME="$(basename "$SCRIPT_HOME")"


# ----- modify default settings -----

JS_MAJOR_DEFAULT="2.3"
JS_RELEASE_DEFAULT="2.3.1-SNAPSHOT"

# ----- modify default settings -----


move_versioned_files()
{
  # $1 = filename
  # $2 = max. versions
  # $3 = number of padding digits for versioned filename

  fbase=$1
  fname="$fbase-$(printf "%0$3d" "$2")"
  number=$2

  while [ $number -gt 0 ]; do
    fname="$fbase-$(printf "%0$3d" "$number")"

    if [ -e "$fname" ] 
    then
      if [ $number = $2 ]
      then
        # echo ".... removing earliest version of file: $fname"
        rm -f $fname
      else
        # echo ".... moving file $fname to "$fbase-$(printf "%0$3d" "$(($number+1))")" "
        mv $fname "$fbase-$(printf "%0$3d" "$(($number+1))")"
      fi
    fi

    number=$(($number-1))
  done
}

JS_FORCE=0
JS_VERSIONS=1

if [ -f "$HOME/.js_profile_${SCRIPT_FOLDER}" ]
then
  echo ".. running profile: $HOME/.js_profile_${SCRIPT_FOLDER}"

  if [ ! -x "$HOME/.js_profile_${SCRIPT_FOLDER}" ]
  then
    chmod u+x $HOME/.js_profile_${SCRIPT_FOLDER}
  fi

  . $HOME/.js_profile_${SCRIPT_FOLDER}
fi

if [ -f "$HOME/.js_profile_${SCRIPT_FOLDER}_$IMAGE_NAME" ]
then
  echo ".. running profile: $HOME/.js_profile_${SCRIPT_FOLDER}_$IMAGE_NAME"

  if [ ! -x "$HOME/.js_profile_${SCRIPT_FOLDER}_$IMAGE_NAME" ]
  then
    chmod u+x $HOME/.js_profile_${SCRIPT_FOLDER}_$IMAGE_NAME
  fi

  . $HOME/.js_profile_${SCRIPT_FOLDER}_$IMAGE_NAME
fi


JS_MAJOR=${JS_MAJOR:-$JS_MAJOR_DEFAULT}
JS_RELEASE=${JS_RELEASE:-$JS_RELEASE_DEFAULT}

case "$IMAGE_NAME" in
  *agent*)      JS_DOWNLOAD_FILE_DEFAULT="js7_agent_unix.$JS_RELEASE.tar.gz"
                ;;
  *controller*) JS_DOWNLOAD_FILE_DEFAULT="js7_controller_unix.$JS_RELEASE.tar.gz"
                ;;
  *joc*)        JS_DOWNLOAD_FILE_DEFAULT="js7_joc_linux.$JS_RELEASE.tar.gz"
                ;;
esac

JS_DOWNLOAD_URL_DEFAULT="https://download.sos-berlin.com/JobScheduler.$JS_MAJOR_DEFAULT/$JS_DOWNLOAD_FILE_DEFAULT"

if [[ $JS_RELEASE == *"SNAPSHOT"* ]]
then
   JS_DOWNLOAD_MOUNT_DEFAULT="/mnt/releases/scheduler_setups/current/$JS_DOWNLOAD_FILE_DEFAULT"
else
  JS_DOWNLOAD_MOUNT_DEFAULT="/mnt/releases/scheduler_setups/$JS_RELEASE/$JS_DOWNLOAD_FILE_DEFAULT"
fi

JS_DOWNLOAD_FILE=${JS_DOWNLOAD_FILE:-$JS_DOWNLOAD_FILE_DEFAULT}
JS_DOWNLOAD_URL=${JS_DOWNLOAD_URL:-$JS_DOWNLOAD_URL_DEFAULT}
JS_DOWNLOAD_MOUNT=${JS_DOWNLOAD_MOUNT:-$JS_DOWNLOAD_MOUNT_DEFAULT}


for option in "$@"
do
  case "$option" in
         -force)           JS_FORCE=1
                           ;;
         --versions=*)     JS_VERSIONS=`echo "$option" | sed 's/--versions=//'`
                           ;;
         *)                echo "unknown argument: $option"
                           exit 1
                           ;;
  esac
done

if [ $JS_VERSIONS = 1 ]
then
  target_filename="$SCRIPT_HOME/build/$JS_DOWNLOAD_FILE"
else
  target_filename="$SCRIPT_HOME/build/$JS_DOWNLOAD_FILE-$(printf "%03d" "1")"
  move_versioned_files $SCRIPT_HOME/build/$JS_DOWNLOAD_FILE $JS_VERSIONS 3
fi

if [ "$JS_FORCE" = "1" ]
then
  echo ".... download $JS_DOWNLOAD_URL to $target_filename"
  curl "$JS_DOWNLOAD_URL" --output $target_filename
else
  echo ".... copy $JS_DOWNLOAD_MOUNT to $target_filename"
  cp -p --remove-destination $JS_DOWNLOAD_MOUNT $target_filename
fi

if [ $JS_VERSIONS -gt 1 ]
then
  # symlinks not supported by Docker
  # ln -f -s $target_filename $SCRIPT_HOME/build/$JS_DOWNLOAD_FILE
  cp -p $target_filename $SCRIPT_HOME/build/$JS_DOWNLOAD_FILE
fi

unset JS_MAJOR
unset JS_RELEASE
unset JS_FORCE
unset JS_VERSIONS
unset JS_DOWNLOAD_FILE
unset JS_DOWNLOAD_URL
unset JS_DOWNLOAD_MOUNT

