#!/bin/sh

set -e

SCRIPT_HOME=$(dirname "$0")
SCRIPT_HOME="`cd \"${SCRIPT_HOME}\" >/dev/null && pwd`"
SCRIPT_FOLDER="`basename $(dirname "$SCRIPT_HOME")`"

IMAGE_NAME="$(basename "$SCRIPT_HOME")"

remove_volumes()
{
  for v in ${JS_VOLUMES[@]}; do
    vol=$(docker volume ls -q --filter "name=$IMAGE_NAME-$v")
    if [ ! -z "$vol" ]
    then
      echo ".. removing volume: $vol"
      docker volume rm $vol
      rm -f $SCRIPT_HOME/$v
    fi
  done
}

create_volumes()
{
  for v in ${JS_VOLUMES[@]}; do
    # create volume for configuration files and log files
    echo ".. creating volume: $IMAGE_NAME-$v"
    docker volume create --name=$IMAGE_NAME-$v

    # make the current user the owner of volume files
    sudo chown -R $USER:$USER $JS_DOCKER_ROOT_DIR/volumes/$IMAGE_NAME-$v

    # create symlink to volume
    if [ -L $SCRIPT_HOME/$v ]
    then
      rm $SCRIPT_HOME/$v
    fi

    ln -s $JS_DOCKER_ROOT_DIR/volumes/$IMAGE_NAME-$v/_data/ $SCRIPT_HOME/$v
  done
}

# Docker Root Directory typically in: /var/lib/docker
JS_DOCKER_ROOT_DIR=$(docker system info | grep 'Docker Root Dir: ' | sed 's/Docker Root Dir: //')

JS_FORCE=0
JS_REMOVE=0

case "$IMAGE_NAME" in
  *agent*)      JS_VOLUMES_DEFAULT=("files" "var")
                ;;
  *controller*) JS_VOLUMES_DEFAULT=("logs" "state")
                ;;
  *joc*)        JS_VOLUMES_DEFAULT=("logs" "config")
                ;;
esac

if [ -f "$HOME/.js_profile_${SCRIPT_FOLDER}_$IMAGE_NAME" ]
then
  echo ".. running profile: $HOME/.js_profile_${SCRIPT_FOLDER}_$IMAGE_NAME"

  if [ ! -x "$HOME/.js_profile_${SCRIPT_FOLDER}_$IMAGE_NAME" ]
  then
    chmod u+x $HOME/.js_profile_${SCRIPT_FOLDER}_$IMAGE_NAME
  fi

  . $HOME/.js_profile_${SCRIPT_FOLDER}_$IMAGE_NAME
fi

for option in "$@"
do
  case "$option" in
         --vol=*) JS_VOLUMES=(`echo "$option" | sed 's/--vol=//' | sed -r 's/[,]+/ /g'`)
                  ;;
         -force)  JS_FORCE=1
                  ;;
         -remove) JS_REMOVE=1
                  ;;
         *)       echo "unknown argument: $option"
                  exit 1
                  ;;
  esac
done

if [ -z "$JS_VOLUMES" ]
then
  JS_VOLUMES=(${JS_VOLUMES_DEFAULT[@]})
fi

if [ "$JS_FORCE" = "1" ] || [ "$JS_REMOVE" = "1" ]
then
    remove_volumes
fi

if [ "$JS_REMOVE" = "0" ]
then
  create_volumes
fi

unset JS_DOCKER_ROOT_DIR
unset JS_FORCE
unset JS_REMOVE
unset JS_VOLUMES

