#!/bin/sh

set -e

SCRIPT_HOME=$(dirname "$0")
SCRIPT_HOME="`cd \"${SCRIPT_HOME}\" >/dev/null && pwd`"
SCRIPT_FOLDER="`basename $(dirname "$SCRIPT_HOME")`"


# ----- modify default settings -----

JS_REPOSITORY="sosberlin/jobscheduler"
JS_IMAGE="$(basename "$SCRIPT_HOME")"

JS_RELEASE_DEFAULT="2.3.0-SNAPSHOT"

JS_USER_ID_DEFAULT="$UID"
JS_NETWORK_DEFAULT="js2"

JS_HTTP_PORT="4446"
JS_HTTPS_PORT="4443"

# example: set max. heap size, enable ssl logging
# JS_JAVA_OPTIONS_DEFAULT="-Xmx2g -Djavax.net.debug=ssl"
JS_JAVA_OPTIONS_DEFAULT="-Xmx500m"

JS_BUILD_ARGS_DEFAULT=

# ----- modify default settings -----


if [ -f "$HOME/.js_profile_${SCRIPT_FOLDER}" ]
then
  echo ".. running profile: $HOME/.js_profile_${SCRIPT_FOLDER}"

  if [ ! -x "$HOME/.js_profile_${SCRIPT_FOLDER}" ]
  then
    chmod u+x $HOME/.js_profile_${SCRIPT_FOLDER}
  fi

  . $HOME/.js_profile_${SCRIPT_FOLDER}
fi

if [ -f "$HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE" ]
then
  echo ".. running profile: $HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE"

  if [ ! -x "$HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE" ]
  then
    chmod u+x $HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE
  fi

  . $HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE
fi


JS_RELEASE="${JS_RELEASE:-$JS_RELEASE_DEFAULT}"
JS_USER_ID="${JS_USER_ID:-$JS_USER_ID_DEFAULT}"
JS_NETWORK="${JS_NETWORK:-$JS_NETWORK_DEFAULT}"
JS_HTTP_PORT="${JS_HTTP_PORT:-$JS_HTTP_PORT_DEFAULT}"
JS_HTTPS_PORT="${JS_HTTPS_PORT:-$JS_HTTPS_PORT_DEFAULT}"
JS_JAVA_OPTIONS="${JS_JAVA_OPTIONS:-$JS_JAVA_OPTIONS_DEFAULT}"
JS_BUILD_ARGS="${JS_BUILD_ARGS:-$JS_BUILD_ARGS_DEFAULT}"

set -x

export DOCKER_BUILDKIT=0

docker build --no-cache --rm \
      --tag=$JS_REPOSITORY:$JS_IMAGE \
      --file=$SCRIPT_HOME/build/Dockerfile \
      --network=$JS_NETWORK \
      --build-arg="JS_RELEASE=$JS_RELEASE" \
      --build-arg="JS_RELEASE_MAJOR=$(echo $JS_RELEASE | cut -d . -f 1,2)" \
      --build-arg="JS_USER_ID=$JS_USER_ID" \
      --build-arg="JS_HTTP_PORT=$JS_HTTP_PORT" \
      --build-arg="JS_HTTPS_PORT=$JS_HTTPS_PORT" \
      --build-arg="JS_JAVA_OPTIONS=$JS_JAVA_OPTIONS" \
      $JS_BUILD_ARGS $SCRIPT_HOME/build

set +x

unset JS_REPOSITORY
unset JS_IMAGE
unset JS_RELEASE
unset JS_USER_ID
unset JS_NETWORK
unset JS_HTTP_PORT
unset JS_HTTPS_PORT
unset JS_JAVA_OPTIONS
unset JS_BUILD_ARGS

