#!/bin/sh

set -e

SCRIPT_HOME=$(dirname "$0")
SCRIPT_HOME="`cd \"${SCRIPT_HOME}\" >/dev/null && pwd`"
SCRIPT_FOLDER="`basename $(dirname "$SCRIPT_HOME")`"


# ----- modify default settings -----

JS_REPOSITORY="sosberlin/jobscheduler"
JS_IMAGE="$(basename "$SCRIPT_HOME")"

JS_USER_ID_DEFAULT="$(id -u $USER):$(id -g $USER)"
JS_NETWORK_DEFAULT="js2"

JS_HTTP_PORT_DEFAULT="7546"
JS_HTTPS_PORT_DEFAULT="7543"

JS_HTTP_PORT_BUILD="4446"
JS_HTTPS_PORT_BUILD="4443"

# example: set max. heap size, enable ssl logging
# JS_JAVA_OPTIONS_DEFAULT="-Xmx1g -Djavax.net.debug=all"
JS_JAVA_OPTIONS_DEFAULT="$JAVA_OPTIONS"

JS_RUN_ARGS_DEFAULT=

# ----- modify default settings -----


if [ -f "$HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE" ]
then
  echo ".. running profile: $HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE"

  if [ ! -x "$HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE" ]
  then
    chmod u+x $HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE
  fi

  . $HOME/.js_profile_${SCRIPT_FOLDER}_$JS_IMAGE
fi

JS_USER_ID="${JS_USER_ID:-$JS_USER_ID_DEFAULT}"
JS_NETWORK="${JS_NETWORK:-$JS_NETWORK_DEFAULT}"
JS_HTTP_PORT="${JS_HTTP_PORT:-$JS_HTTP_PORT_DEFAULT}"
JS_HTTPS_PORT="${JS_HTTPS_PORT:-$JS_HTTPS_PORT_DEFAULT}"
JS_JAVA_OPTIONS="${JS_JAVA_OPTIONS:-$JS_JAVA_OPTIONS_DEFAULT}"
JS_RUN_ARGS="${JS_RUN_ARGS:-$JS_RUN_ARGS_DEFAULT}"

set -x

docker run -dit --rm \
      --hostname=$JS_IMAGE \
      --network=$JS_NETWORK \
      --publish=$JS_HTTP_PORT:$JS_HTTP_PORT_BUILD \
      --publish=$JS_HTTPS_PORT:$JS_HTTPS_PORT_BUILD \
      --env="RUN_JS_HTTP_PORT=$JS_HTTP_PORT_BUILD" \
      --env="RUN_JS_HTTPS_PORT=$JS_HTTPS_PORT_BUILD" \
      --env="RUN_JS_JAVA_OPTIONS=$JS_JAVA_OPTIONS" \
      --env="RUN_JS_USER_ID=$JS_USER_ID" \
      --mount="type=volume,src=$JS_IMAGE-config,dst=/var/sos-berlin.com/js7/joc/resources/joc" \
      --mount="type=volume,src=$JS_IMAGE-logs,dst=/var/log/sos-berlin.com/js7/joc" \
      --name $JS_IMAGE \
      $JS_RUN_ARGS $JS_REPOSITORY:$JS_IMAGE

#     --env="RUN_JS_JAVA_OPTIONS=$JS_JAVA_OPTIONS -Djavax.net.debug=all -Djavax.net.ssl.trustStore=/var/sos-berlin.com/js7/joc/resources/joc/https-truststore.p12 -Djavax.net.ssl.trustStorePassword=jobscheduler" 

set +x

unset JS_REPOSITORY
unset JS_IMAGE
unset JS_USER_ID
unset JS_NETWORK
unset JS_HTTP_PORT
unset JS_HTTPS_PORT
unset JS_HTTP_PORT_BUILD
unset JS_HTTPS_PORT_BUILD
unset JS_JAVA_OPTIONS
unset JS_RUN_ARGS

